Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(496)

Unified Diff: runtime/vm/profiler.cc

Issue 2503623003: Revert "JumpToFrame refactor" (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/exceptions.cc ('k') | runtime/vm/simulator_arm.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/profiler.cc
diff --git a/runtime/vm/profiler.cc b/runtime/vm/profiler.cc
index 22febb0dabbe8ba3a1fefe4ecea920912cc93028..05f830292c76c03c54568a4fac18debcebb55717 100644
--- a/runtime/vm/profiler.cc
+++ b/runtime/vm/profiler.cc
@@ -1104,10 +1104,11 @@ void Profiler::SampleThread(Thread* thread,
return;
}
- if (StubCode::HasBeenInitialized() && StubCode::InJumpToFrameStub(state.pc)) {
- // The JumpToFrame stub manually adjusts the stack pointer, frame
- // pointer, and some isolate state. It is not safe to walk the
- // stack when executing this stub.
+ if (StubCode::HasBeenInitialized() &&
+ StubCode::InJumpToExceptionHandlerStub(state.pc)) {
+ // The JumpToExceptionHandler stub manually adjusts the stack pointer,
+ // frame pointer, and some isolate state before jumping to a catch entry.
+ // It is not safe to walk the stack when executing this stub.
AtomicOperations::IncrementInt64By(
&counters_.bail_out_jump_to_exception_handler, 1);
return;
« no previous file with comments | « runtime/vm/exceptions.cc ('k') | runtime/vm/simulator_arm.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698